denormalize_spct: Undo previously applied normalization

View source: R/spct.normalize.r

denormalize_spctR Documentation

Undo previously applied normalization

Description

Undo previously applied normalization

Usage

denormalize_spct(spct, wipe.away = FALSE)

Arguments

spct

A generic_spct object or a generic_mspct object, or objects of derived classes.

wipe.away

logical If TRUE the normalization metadata is removed without undoing the effect of the normalization, and otherwise after restoring the spectral data to its original scaling.

Value

A modified copy of spct if it was previously normalized or spct unchanged, otherwise.


photobiology documentation built on March 15, 2026, 9:06 a.m.