Learn R Programming

photobiology (version 0.9.4)

fscale: Rescale a spectrum using a summary function

Description

These functions return a spectral object of the same class as the one supplied as argument but with the spectral data rescaled.

Usage

fscale(x, ...)

## S3 method for class 'default':
fscale(x, ...)

## S3 method for class 'source_spct':
fscale(x, range = NULL, f = "mean",
  unit.out = getOption("photobiology.radiation.unit", default = "energy"),
  ...)

## S3 method for class 'response_spct':
fscale(x, range = NULL, f = "mean",
  unit.out = getOption("photobiology.radiation.unit", default = "energy"),
  ...)

## S3 method for class 'filter_spct':
fscale(x, range = NULL, f = "mean",
  qty.out = getOption("photobiology.filter.qty", default = "transmittance"),
  ...)

## S3 method for class 'reflector_spct':
fscale(x, range = NULL, f = "mean",
  qty.out = NULL, ...)

## S3 method for class 'source_mspct':
fscale(x, range = NULL, f = "mean",
  unit.out = getOption("photobiology.radiation.unit", default = "energy"),
  ...)

## S3 method for class 'response_mspct':
fscale(x, range = NULL, f = "mean",
  unit.out = getOption("photobiology.radiation.unit", default = "energy"),
  ...)

## S3 method for class 'filter_mspct':
fscale(x, range = NULL, f = "mean",
  qty.out = getOption("photobiology.filter.qty", default = "transmittance"),
  ...)

## S3 method for class 'reflector_mspct':
fscale(x, range = NULL, f = "mean",
  qty.out = NULL, ...)

## S3 method for class 'default':
fshift(x, ...)

Arguments

x
An R object
...
additonal named arguments passed down to f.
range
An R object on which range() returns a numeric vector of length 2 with the limits of a range of wavelengths in nm, with min annd max wavelengths (nm)
f
character string "mean" or "total" for scaling so taht this summary value becomes 1 for the returned object, or the name of a function taking x as first argument and returning a numeric value.
unit.out
character Alowed values "energy", and "photon", or its alias "quantum"
qty.out
character Allowed values "transmittance", and "absorbance"

Value

  • a new object of the same class as x. a new object of the same class as x.

Methods (by class)

  • default: Default for generic function
  • source_spct:
  • response_spct:
  • filter_spct:
  • reflector_spct:
  • source_mspct:
  • response_mspct:
  • filter_mspct:
  • reflector_mspct:
  • default: Default for generic function

See Also

Other rescaling functions: fshift, getNormalized, is_normalized, is_scaled, normalize, setNormalized, setScaled