getSensorProperties: Get the "sensor.properties" attribute

View source: R/spct.classes.r

getSensorPropertiesR Documentation

Get the "sensor.properties" attribute

Description

Function to read the "sensor.properties" attribute of an existing source_spct or a source_mspct.

Usage

getSensorProperties(x, ...)

sensor_properties(x, ...)

## Default S3 method:
getSensorProperties(x, return.null = FALSE, ...)

## S3 method for class 'response_spct'
getSensorProperties(x, return.null = FALSE, ...)

## S3 method for class 'summary_response_spct'
getSensorProperties(x, return.null = FALSE, ...)

## S3 method for class 'generic_mspct'
getSensorProperties(x, ..., idx = getIdFactor(x))

Arguments

x

a source_spct object

...

Allows use of additional arguments in methods for other classes.

return.null

logical If true, NULL is returned if the attribute is not set, otherwise the expected list is returned with all fields set to NA.

idx

character Name of the column with the names of the members of the collection of spectra.

Value

an object of class sensor_properties derived from list, guaranteed to contain fields named "sensor.name", "sensor.type" and "num.channels". If the attribute is not set, these fields are set to NA in the returned object.

Note

The method for collections of spectra returns a tibble with a column of lists.

See Also

Other measurement metadata functions: add_attr2tb(), getFilterProperties(), getHowMeasured(), getInstrDesc(), getInstrSettings(), getSoluteProperties(), getWhatMeasured(), getWhenMeasured(), getWhereMeasured(), get_attributes(), isValidInstrDesc(), isValidInstrSettings(), select_spct_attributes(), setFilterProperties(), setHowMeasured(), setInstrDesc(), setInstrSettings(), setSensorProperties(), setSoluteProperties(), setWhatMeasured(), setWhenMeasured(), setWhereMeasured(), spct_attr2tb(), spct_metadata(), subset_attributes(), trimInstrDesc(), trimInstrSettings()

Examples

sensor_properties(ccd.spct)


photobiology documentation built on March 15, 2026, 9:06 a.m.