Learn R Programming

photobiology (version 0.9.5)

getWhenMeasured.generic_mspct: Get the "when.measured" attribute

Description

Function to read the "when.measured" attribute of an existing generic_spct or a generic_mspct.

Usage

## S3 method for class 'generic_mspct':
getWhenMeasured(x, ..., idx = !is.null(names(x)))

getWhenMeasured(x, ...)

## S3 method for class 'default':
getWhenMeasured(x, ...)

## S3 method for class 'generic_spct':
getWhenMeasured(x, ...)

## S3 method for class 'summary_generic_spct':
getWhenMeasured(x, ...)

Arguments

x
a generic_spct object
...
Allows use of additional arguments in methods for other classes.
idx
logical whether to add a column with the names of the elements of spct

Value

  • POSIXct An object with date and time.

Methods (by class)

  • generic_mspct: generic_mspct
  • default: default
  • generic_spct: generic_spct
  • summary_generic_spct: summary_generic_spct

See Also

Other measurement metadata functions: getInstrDesc, getInstrSettings, getWhereMeasured.generic_mspct, setInstrDesc, setInstrSettings, setWhenMeasured.generic_mspct, setWhereMeasured.generic_mspct

Examples

Run this code
getWhenMeasured(sun.spct)

Run the code above in your browser using DataLab