Usage
irrad(spct, w.band, unit.out, quantity, time.unit, wb.trim, use.cached.mult,
use.hinges, allow.scaled, ...)# S3 method for default
irrad(spct, w.band, unit.out, quantity, time.unit, wb.trim,
use.cached.mult, use.hinges, allow.scaled, ...)
# S3 method for source_spct
irrad(spct, w.band = NULL,
unit.out = getOption("photobiology.radiation.unit", default = "energy"),
quantity = "total", time.unit = NULL,
wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
use.cached.mult = getOption("photobiology.use.cached.mult", default =
FALSE), use.hinges = getOption("photobiology.use.hinges"),
allow.scaled = !quantity %in% c("average", "mean", "total"), ...)
# S3 method for source_mspct
irrad(spct, w.band = NULL,
unit.out = getOption("photobiology.radiation.unit", default = "energy"),
quantity = "total", time.unit = NULL,
wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
use.cached.mult = getOption("photobiology.use.cached.mult", default =
FALSE), use.hinges = NULL, allow.scaled = !quantity %in% c("average",
"mean", "total"), ..., idx = !is.null(names(spct)))
Arguments
w.band
waveband or list of waveband objects The waveband(s) determine
the region(s) of the spectrum that are summarized.
unit.out
character string with allowed values "energy", and "photon",
or its alias "quantum"
quantity
character string One of "total", "average" or "mean",
"contribution", "contribution.pc", "relative" or "relative.pc"
time.unit
character or lubridate::duration
wb.trim
logical if TRUE wavebands crossing spectral data boundaries
are trimmed, if FALSE, they are discarded
use.cached.mult
logical indicating whether multiplier values should be
cached between calls
use.hinges
logical indicating whether to use hinges to reduce
interpolation errors
allow.scaled
logical indicating whether scaled or normalized spectra
as argument to spct are flagged as an error
...
other arguments (possibly ignored)
idx
logical whether to add a column with the names of the elements of
spct