View source: R/waveband.class.r
| is_effective | R Documentation |
A generic function for querying if a biological spectral weighting function (BSWF) has been applied to an object or is included in its definition.
is_effective(x)
## Default S3 method:
is_effective(x)
## S3 method for class 'waveband'
is_effective(x)
## S3 method for class 'generic_spct'
is_effective(x)
## S3 method for class 'source_spct'
is_effective(x)
## S3 method for class 'summary_generic_spct'
is_effective(x)
## S3 method for class 'summary_source_spct'
is_effective(x)
x |
an R object |
A logical.
Other waveband attributes:
labels,
normalization()
is_effective(summary(sun.spct))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.