is_effective.summary_generic_spct: Is an R object "effective"
Description
A generic function for quering if a biological spectral weighting function
(BSWF) has been applied to an object or is included in its definition.
Usage
## S3 method for class 'summary_generic_spct':
is_effective(x)
## S3 method for class 'summary_source_spct':
is_effective(x)
is_effective(x)
## S3 method for class 'default':
is_effective(x)
## S3 method for class 'waveband':
is_effective(x)
## S3 method for class 'generic_spct':
is_effective(x)
## S3 method for class 'source_spct':
is_effective(x)
Arguments
x
an R object
Value
A logical.
Methods (by class)
summary_generic_spct: Does asummary_generic_spctobject contain
a summary of effective spectral irradiance values.
summary_source_spct: Does asummary_source_spctobject contain
a summary of effective spectral irradiance values.
default: Default method.
waveband: Is awavebandobject defining a method for
calcualtaing effective irradiance.
generic_spct: Does asource_spctobject contain effective
spectral irradiance values.
source_spct: Does asource_spctobject contain effective
spectral irradiance values.