Learn R Programming

photobiology (version 0.9.4)

max.generic_mspct: Maximun wavelength

Description

Maximun function for spectra, returning wavelength maximum.

Usage

## S3 method for class 'generic_mspct':
max(..., na.rm = FALSE, idx = NULL)

## S3 method for class 'generic_spct':
max(..., na.rm = FALSE)

Arguments

...
not used in current version
na.rm
a logical indicating whether missing values should be removed.
idx
logical whether to add a column with the names of the elements of spct

See Also

Other wavelength summaries: midpoint.generic_mspct, min.generic_mspct, min.waveband, range.generic_mspct, range.waveband, stepsize.generic_mspct

Examples

Run this code
max(sun.spct)

Run the code above in your browser using DataLab