print.generic_mspct: Print a spectral collection object
Description
Print method for objects of the collection of spectra classes. Any object
of a class derived from geenric_mspct is printed with this method.Usage
## S3 method for class 'generic_mspct':
print(x, ..., n = NULL, width = NULL)
Arguments
x
generic_mspct A collection of spectra
...
not used in current version
n
Number of rows to show for each member spectrum.
width
Width of text output to generate.