Learn R Programming

photobiology (version 0.9.4)

put_hinges: Insert interpolated spectral irradiance values.

Description

Inserting wavelengths values immediately before and after a discontinuity in the SWF, greatly reduces the errors caused by interpolating the weighted irradiance during integration of the effective spectral irradiance. This is specially true when data has a large wavelength step size.

Arguments

x
numeric array of wavelength (nm)
y
numeric array of spectral irradiance values
hinges
a numeric array giving the wavelengths at which the s.irrad should be inserted by interpolation, no interpolation is indicated by an empty array (numeric(0))

Value

  • a numeric vector