## S3 method for class 'source_mspct':
qe_ratio(spct, w.band = NULL,
wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
use.cached.mult = getOption("photobiology.use.cached.mult", default =
FALSE), use.hinges = getOption("photobiology.use.hinges", default = NULL),
..., idx = !is.null(names(spct)))
qe_ratio(spct, w.band, wb.trim, use.cached.mult, use.hinges, ...)
## S3 method for class 'default':
qe_ratio(spct, w.band, wb.trim, use.cached.mult, use.hinges,
...)
## S3 method for class 'source_spct':
qe_ratio(spct, w.band = NULL,
wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
use.cached.mult = getOption("photobiology.use.cached.mult", default =
FALSE), use.hinges = getOption("photobiology.use.hinges", default = NULL),
...)numeric values giving number of moles of photons
per Joule for each waveband, with name attribute set to the name of each
waveband unless a named list of wavebands is supplied in which case the
names of the list elements are used, with "q:e" prepended..source_mspct: Calculates photon:energy ratio from asource_mspctobject.default: Default for generic functionsource_spct: Method forsource_spctobjectse_ratio.source_mspct,
energy_ratio,
eq_ratio.source_mspct,
photon_ratio,
photons_energy_ratio,
q_ratio.source_mspctqe_ratio(sun.spct, new_waveband(400,700))Run the code above in your browser using DataLab