Learn R Programming

photobiology (version 0.9.4)

range.generic_mspct: Range of wavelength

Description

Range function for spectra, returning wavelength range.

Usage

## S3 method for class 'generic_mspct':
range(..., na.rm = FALSE, idx = NULL)

## S3 method for class 'generic_spct':
range(..., na.rm = FALSE)

Arguments

...
not used in current version
na.rm
a logical indicating whether missing values should be removed.
idx
logical whether to add a column with the names of the elements of spct

See Also

Other wavelength summaries: max.generic_mspct, midpoint.generic_mspct, min.generic_mspct, min.waveband, range.waveband, stepsize.generic_mspct

Examples

Run this code
range(sun.spct)

Run the code above in your browser using DataLab