Method returning attributes of an object of class generic_spct or derived,
or of class waveband. Only attributes defined and/or set by package
'photobiology' for objects of the corresponding class are returned. Parameter
which can be used to subset each attribute when a generic_spct object
with multiple spectra in long form is subset.
subset_attributes(x, to.keep, ...)# S3 method for default
subset_attributes(x, to.keep, ...)
# S3 method for generic_spct
subset_attributes(
x,
to.keep = character(),
target.attributes = spct_attributes(class(x)[1]),
...
)
Named list of attribute values.
a generic_spct object.
character vector Indices to the spectra for which attributes are to be extracted and retained.
currently ignored
character vector Names of attributes to be
subset using which.
The values in which are passed as argument to the extract
operator only if the value of the attribute is a list of the same length
as the logical vector passed as argument to which.
select_spct_attributes
Other measurement metadata functions:
add_attr2tb(),
getFilterProperties(),
getHowMeasured(),
getInstrDesc(),
getInstrSettings(),
getSensorProperties(),
getSoluteProperties(),
getWhatMeasured(),
getWhenMeasured(),
getWhereMeasured(),
get_attributes(),
isValidInstrDesc(),
isValidInstrSettings(),
select_spct_attributes(),
setFilterProperties(),
setHowMeasured(),
setInstrDesc(),
setInstrSettings(),
setSensorProperties(),
setSoluteProperties(),
setWhatMeasured(),
setWhenMeasured(),
setWhereMeasured(),
spct_attr2tb(),
spct_metadata(),
trimInstrDesc(),
trimInstrSettings()