| trim_wl | R Documentation |
Trim head and tail of a spectrum based on wavelength limits, with interpolation at range boundaries used by default. Expansion is also possible.
trim_wl(x, range, use.hinges, fill, ...)
## Default S3 method:
trim_wl(x, range, use.hinges, fill, ...)
## S3 method for class 'generic_spct'
trim_wl(x, range = NULL, use.hinges = TRUE, fill = NULL, ...)
## S3 method for class 'generic_mspct'
trim_wl(
x,
range = NULL,
use.hinges = TRUE,
fill = NULL,
...,
.parallel = FALSE,
.paropts = NULL
)
## S3 method for class 'waveband'
trim_wl(
x,
range = NULL,
use.hinges = TRUE,
fill = NULL,
trim = getOption("photobiology.waveband.trim", default = TRUE),
...
)
## S3 method for class 'list'
trim_wl(
x,
range = NULL,
use.hinges = TRUE,
fill = NULL,
trim = getOption("photobiology.waveband.trim", default = TRUE),
...
)
x |
an R object. |
range |
a numeric vector of length two, or any other object for which function range() will return two. |
use.hinges |
logical Flag indicating whether to insert "hinges" into the spectral data before integration so as to reduce interpolation errors at the boundaries of the wavebands. |
fill |
if |
... |
ignored (possibly used by derived methods). |
.parallel |
if TRUE, apply function in parallel, using parallel backend provided by foreach |
.paropts |
a list of additional options passed into the foreach function when parallel computation is enabled. This is important if (for example) your code relies on external data or packages: use the .export and .packages arguments to supply them so that all cluster nodes have the correct environment set up for computing. |
trim |
logical (default is TRUE which trims the wavebands at the boundary, while FALSE discards wavebands that are partly off-boundary). |
A copy of x, usually trimmed or expanded to a different
length, either shorter or longer. Possibly with some of the original
spectral data values replaced with fill.
By default the w.length values for the first and last rows
in the returned object are the values supplied as range.
trim_wl when applied to waveband objects always inserts hinges when trimming.
trim_wl when applied to waveband objects always inserts hinges when trimming.
Other trim functions:
clip_wl(),
trim_spct(),
trim_waveband()
trim_wl(sun.spct, range = c(400, 500))
trim_wl(sun.spct, range = c(NA, 500))
trim_wl(sun.spct, range = c(400, NA))
trim_wl(sun_evening.spct)
trim_wl(sun_evening.mspct)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.