untag(x, ...)# S3 method for default
untag(x, ...)
# S3 method for generic_spct
untag(x, byref = FALSE, ...)
# S3 method for generic_mspct
untag(x, byref = FALSE, ...)
x contains tag data they are removed and the "spct.tags"
atrribute is set to NA, while if x has no tags, it is not
modified. In either case, the byref argument is respected: in all cases if
byref = FALSE a copy of x is returned.default: Default for generic function generic_spct: Specialization for generic_spct generic_mspct: Specialization for generic_spct
is_tagged,
tag, wb2rect_spct,
wb2spct, wb2tagged_spct