A dataset containing wavelengths at a 5 nm interval (300 nm to 830 nm) and the corresponding spectral energy irradiance normalized to 1 at 560 nm. Spectrum approximates the midday solar spectrum at middle latitude as 'corresponds' to the white point of a black body a 6504 K. Original data from http://files.cie.co.at/204.xls downloaded on 2014-07-25 The variables are as follows:
A source spectrum with 107 rows and 2 variables
w.length (nm)
s.e.irrad (rel. units)
Other Spectral data examples: A.illuminant.spct,
black_body.spct, ccd.spct,
clear.spct, clear_body.spct,
filter_cps.mspct,
green_leaf.spct,
photodiode.spct,
polyester.spct,
sun.daily.data,
sun.daily.spct, sun.data,
sun.spct, white_body.spct,
white_led.cps_spct,
white_led.raw_spct,
white_led.source_spct,
yellow_gel.spct