powered by
Clip head and tail of a spectrum based on wavelength limits, no interpolation used at range boundaries.
clip_wl(x, range, ...)# S3 method for default clip_wl(x, range, ...)# S3 method for generic_spct clip_wl(x, range = NULL, ...)# S3 method for generic_mspct clip_wl(x, range = NULL, expand = TRUE, ...)# S3 method for waveband clip_wl(x, range = NULL, ...)# S3 method for list clip_wl(x, range = NULL, ...)
# S3 method for default clip_wl(x, range, ...)
# S3 method for generic_spct clip_wl(x, range = NULL, ...)
# S3 method for generic_mspct clip_wl(x, range = NULL, expand = TRUE, ...)
# S3 method for waveband clip_wl(x, range = NULL, ...)
# S3 method for list clip_wl(x, range = NULL, ...)
a spectrum object or a collection of spectral objects of the same class as x with wavelength heads and tails clipped.
x
an R object.
a numeric vector of length two, or any other object for which function range() will return range of wavelengths expressed in nanometres.
range()
ignored (possibly used by derived methods).
logical Expand or not members containing spectra in long form.
Other trim functions: trim_spct(), trim_waveband(), trim_wl()
trim_spct()
trim_waveband()
trim_wl()
clip_wl(sun.spct, range = c(400, 500)) clip_wl(sun.spct, range = c(NA, 500)) clip_wl(sun.spct, range = c(400, NA))
Run the code above in your browser using DataLab