Learn R Programming

photobiology (version 0.14.3)

denormalize_spct: Undo previously applied normalization

Description

Undo previously applied normalization

Usage

denormalize_spct(spct, wipe.away = FALSE)

Value

A modified copy of spct if it was previously normalized or spct unchanged, otherwise.

Arguments

spct

A generic_spct object or a generic_mspct object, or objects of derived classes.

wipe.away

logical If TRUE the normalization metadata is removed without undoing the effect of the normalization, and otherwise after restoring the spectral data to its original scaling.