Undo previously applied normalization
denormalize_spct(spct, wipe.away = FALSE)A modified copy of spct if it was previously normalized or
spct unchanged, otherwise.
A generic_spct object or a generic_mspct object,
or objects of derived classes.
logical If TRUE the normalization metadata is removed
without undoing the effect of the normalization, and otherwise after
restoring the spectral data to its original scaling.