Usage
fshift(x, ...)
## S3 method for class 'source_spct':
fshift(x, range = c(min(x), min(x) + 10), f = "mean",
unit.out = getOption("photobiology.radiation.unit", default = "energy"),
...)
## S3 method for class 'response_spct':
fshift(x, range = c(min(x), min(x) + 10),
f = "mean", unit.out = getOption("photobiology.radiation.unit", default =
"energy"), ...)
## S3 method for class 'filter_spct':
fshift(x, range = c(min(x), min(x) + 10), f = "min",
qty.out = getOption("photobiology.filter.qty", default = "transmittance"),
...)
## S3 method for class 'reflector_spct':
fshift(x, range = c(min(x), min(x) + 10),
f = "min", qty.out = NULL, ...)
## S3 method for class 'source_mspct':
fshift(x, range = c(min(x), min(x) + 10), f = "mean",
unit.out = getOption("photobiology.radiation.unit", default = "energy"),
...)
## S3 method for class 'response_mspct':
fshift(x, range = c(min(x), min(x) + 10),
f = "mean", unit.out = getOption("photobiology.radiation.unit", default =
"energy"), ...)
## S3 method for class 'filter_mspct':
fshift(x, range = c(min(x), min(x) + 10), f = "min",
qty.out = getOption("photobiology.filter.qty", default = "transmittance"),
...)
## S3 method for class 'reflector_mspct':
fshift(x, range = c(min(x), min(x) + 10),
f = "min", qty.out = NULL, ...)Arguments
...
additonal named arguments passed down to f.
range
An R object on which range() returns a numeric vector of
length 2 with the limits of a range of wavelengths in nm, with min annd max
wavelengths (nm)
f
character string "mean", "min" or "max" for scaling so that this
summary value becomes the origin of the spectral data scale in the returned
object, or the name of a function taking x as first argument and
returning a numeric value.
unit.out
character Allowed values "energy", and "photon", or its alias
"quantum"
qty.out
character Allowed values "transmittance", and "absorbance"