| getSensorProperties | R Documentation |
Function to read the "sensor.properties" attribute of an existing source_spct or a source_mspct.
getSensorProperties(x, ...)
sensor_properties(x, ...)
## Default S3 method:
getSensorProperties(x, return.null = FALSE, ...)
## S3 method for class 'response_spct'
getSensorProperties(x, return.null = FALSE, ...)
## S3 method for class 'summary_response_spct'
getSensorProperties(x, return.null = FALSE, ...)
## S3 method for class 'generic_mspct'
getSensorProperties(x, ..., idx = getIdFactor(x))
x |
a source_spct object |
... |
Allows use of additional arguments in methods for other classes. |
return.null |
logical If true, |
idx |
character Name of the column with the names of the members of the collection of spectra. |
an object of class sensor_properties derived from list,
guaranteed to contain fields named "sensor.name",
"sensor.type" and "num.channels". If the
attribute is not set, these fields are set to NA in the returned
object.
The method for collections of spectra returns a tibble with a column of lists.
Other measurement metadata functions:
add_attr2tb(),
getFilterProperties(),
getHowMeasured(),
getInstrDesc(),
getInstrSettings(),
getSoluteProperties(),
getWhatMeasured(),
getWhenMeasured(),
getWhereMeasured(),
get_attributes(),
isValidInstrDesc(),
isValidInstrSettings(),
select_spct_attributes(),
setFilterProperties(),
setHowMeasured(),
setInstrDesc(),
setInstrSettings(),
setSensorProperties(),
setSoluteProperties(),
setWhatMeasured(),
setWhenMeasured(),
setWhereMeasured(),
spct_attr2tb(),
spct_metadata(),
subset_attributes(),
trimInstrDesc(),
trimInstrSettings()
sensor_properties(ccd.spct)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.