Learn R Programming

photobiology (version 0.14.3)

getSensorProperties: Get the "sensor.properties" attribute

Description

Function to read the "sensor.properties" attribute of an existing source_spct or a source_mspct.

Usage

getSensorProperties(x, ...)

sensor_properties(x, ...)

# S3 method for default getSensorProperties(x, return.null = FALSE, ...)

# S3 method for response_spct getSensorProperties(x, return.null = FALSE, ...)

# S3 method for summary_response_spct getSensorProperties(x, return.null = FALSE, ...)

# S3 method for generic_mspct getSensorProperties(x, ..., idx = getIdFactor(x))

Value

an object of class sensor_properties derived from list, guaranteed to contain fields named "sensor.name",

"sensor.type" and "num.channels". If the attribute is not set, these fields are set to NA in the returned object.

Arguments

x

a source_spct object

...

Allows use of additional arguments in methods for other classes.

return.null

logical If true, NULL is returned if the attribute is not set, otherwise the expected list is returned with all fields set to NA.

idx

character Name of the column with the names of the members of the collection of spectra.

See Also

Other measurement metadata functions: add_attr2tb(), getFilterProperties(), getHowMeasured(), getInstrDesc(), getInstrSettings(), getSoluteProperties(), getWhatMeasured(), getWhenMeasured(), getWhereMeasured(), get_attributes(), isValidInstrDesc(), isValidInstrSettings(), select_spct_attributes(), setFilterProperties(), setHowMeasured(), setInstrDesc(), setInstrSettings(), setSensorProperties(), setSoluteProperties(), setWhatMeasured(), setWhenMeasured(), setWhereMeasured(), spct_attr2tb(), spct_metadata(), subset_attributes(), trimInstrDesc(), trimInstrSettings()

Examples

Run this code
sensor_properties(ccd.spct)

Run the code above in your browser using DataLab