msmsply(mspct, .fun, ...)msdply(mspct, .fun, ..., idx = NULL, col.names = NULL)
mslply(mspct, .fun, ...)
msaply(mspct, .fun, ..., .drop = TRUE)
NULL, the default, a column is added only if all members
of mscpt are named.msmsply a data frame in the case of msdply a list in the case of mslply an array in the case of msaply