| setSensorProperties | R Documentation |
Function to set by reference the "sensor.properties" attribute of an existing response_spct object.
setSensorProperties(x, sensor.properties = NULL, verbose = FALSE)
sensor_properties(x) <- value
x |
a response_spct object |
sensor.properties, value |
a list with fields named as described in Details. |
verbose |
logical Flag to enable warning when applied to object of unsupported class. |
Storing sensor properties in an attribute with a well defined
format and minimum of information is intended to help with reproducibility.
Unlike the filter.properties metadata, the sensor.properties
metadata are currently not used in any computations. The attribute is
intended to be used with photoelectric sensors, broadband and image, i.e.,
not for biological photoreceptors or photobiological responses.
character, identification code or name used by the supplier, required
character, "broadband", "spectral", "image" required
character, required
character, "cosine", "dome", "sphere", "narrow" required
data.frame, description of the channels, one channel per row, optional
character, "analog", "digital", and possibly others.
character, optional
character, optional
character, optional
character, optional
x
This function alters x itself by reference and in addition
returns x invisibly. If x is not a source_spct object,
x is not modified.
Other measurement metadata functions:
add_attr2tb(),
getFilterProperties(),
getHowMeasured(),
getInstrDesc(),
getInstrSettings(),
getSensorProperties(),
getSoluteProperties(),
getWhatMeasured(),
getWhenMeasured(),
getWhereMeasured(),
get_attributes(),
isValidInstrDesc(),
isValidInstrSettings(),
select_spct_attributes(),
setFilterProperties(),
setHowMeasured(),
setInstrDesc(),
setInstrSettings(),
setSoluteProperties(),
setWhatMeasured(),
setWhenMeasured(),
setWhereMeasured(),
spct_attr2tb(),
spct_metadata(),
subset_attributes(),
trimInstrDesc(),
trimInstrSettings()
my.spct <- ccd.spct
sensor_properties(my.spct)
sensor_properties(my.spct) <- NULL
sensor_properties(my.spct)
sensor_properties(my.spct) <- list(model = "ccd",
type = "ABC",
supplier = "unknown")
sensor_properties(my.spct)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.