View source: R/simul-response.R
| simul_sensor_response | R Documentation |
Simulate light sensor response
simul_sensor_response(
source.spct,
sensor.mspct,
norm = "skip",
range = NULL,
unit.out = getOption("photobiology.radiation.unit", default = "energy"),
time.unit = NULL,
scale.factor = 1,
attr2tb = NULL
)
source.spct |
source_spct Light source spectral irradiance. |
sensor.mspct |
response_spct or response_mspct Light sensor spectral responsiveness. |
norm |
numeric Normalization wavelength (nm) or character string
|
range |
numeric vector of length two Range of wavelengths to use (nanometres, nm) |
unit.out |
character Allowed values |
time.unit |
character or lubridate::duration object. |
scale.factor |
numeric vector of length 1, or length equal to that of
|
attr2tb |
character vector, see |
Compute sensor response spectrum by convolution of light source
emission spectrum or illumination spectrum and the responsiveness spectrum
of a sensor with one or more channels. Return the integral over
wavelengths' range for each sensor channel, or sensor in
sensor.mspct.
A data frame
simul_sensor_response(sun.spct, ccd.spct)
simul_sensor_response(sun.spct, ccd.spct, range = c(400, 700))
simul_sensor_response(sun.spct, ccd.spct, unit.out = "photon")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.